@@ -1,4 +1,4 @@
-# rocco // vim: ts=2 sw=2 expandtab
+# vim: ts=2 sw=2 expandtab
 
 # Build information for POE.  Moved into a library so it can be
 # required by Makefile.PL and gen-meta.perl.
@@ -24,37 +24,47 @@ push @ISA, qw(Exporter);
 
 
 sub CONFIG_REQUIREMENTS () {
-  ("POE::Test::Loops"  => '1.311')
+  (
+    "POE::Test::Loops"  => '1.355',
+  );
 }
 
 sub CORE_REQUIREMENTS () {
-  (
+  my @core_requirements = (
     "Carp"              => 0,
     "Errno"             => 1.09,
     "Exporter"          => 0,
     "File::Spec"        => 0.87,
     "IO"                => 1.24,  # MSWin32 blocking(0)
     "IO::Handle"        => 1.27,
+    "IO::Pipely"        => 0.005,
     "POSIX"             => 1.02,
     "Socket"            => 1.7,
     "Storable"          => 2.16,
     "Test::Harness"     => 2.26,
     "Time::HiRes"       => 1.59,
-    (
-      ($^O eq "MSWin32")
-      ? (
-        "Win32::Console" => 0.031,
-        "Win32API::File" => 0.05,
-        "Win32::Job"     => 0.03,
-        "Win32::Process" => 0,
-        "Win32"          => 0,
-      )
-      : (
-        "IO::Tty"        => 1.08, # avoids crashes on fbsd
-      )
-    ),
     CONFIG_REQUIREMENTS,
-  )
+  );
+
+  if ($^O eq "MSWin32") {
+    push @core_requirements, (
+      "Win32::Console" => 0.031,
+      "Win32API::File" => 0.05,
+      "Win32::Job"     => 0.03,
+      "Win32::Process" => 0,
+      "Win32"          => 0,
+    );
+  }
+  elsif ($^O eq 'cygwin') {
+    # Skip IO::Tty.  It has trouble building as of this writing.
+  }
+  else {
+    push @core_requirements, (
+      "IO::Tty"        => 1.08, # avoids crashes on fbsd
+    );
+  }
+
+  return @core_requirements;
 }
 
 sub DIST_AUTHOR () {
